#
# spec file for package kf6-kwidgetsaddons
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.6.0

%define rname kwidgetsaddons
# Full KF6 version (e.g. 6.6.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kwidgetsaddons
Version:        6.6.0
Release:        1.1
Summary:        Large set of desktop widgets
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6UiPlugin) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}

%description
This repository contains add-on widgets and classes for applications
that use the Qt Widgets module.

%package -n libKF6WidgetsAddons6
Summary:        Large set of desktop widgets
Requires:       kf6-kwidgetsaddons >= %{version}

%description -n libKF6WidgetsAddons6
This repository contains add-on widgets and classes for applications
that use the Qt Widgets module.

%package devel
Summary:        Large set of desktop widgets: Build Environment
Requires:       libKF6WidgetsAddons6 = %{version}
Requires:       cmake(Qt6Widgets) >= %{qt6_version}

%description devel
This repository contains add-on widgets and classes for applications
that use the Qt Widgets module.

%lang_package -n libKF6WidgetsAddons6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kwidgetsaddons6 --with-qt --without-mo

%ldconfig_scriptlets -n libKF6WidgetsAddons6

%files
%{_kf6_debugdir}/kwidgetsaddons.categories

%files -n libKF6WidgetsAddons6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6WidgetsAddons.so.*

%files devel
%doc %{_kf6_qchdir}/KF6WidgetsAddons.*
%{_kf6_cmakedir}/KF6WidgetsAddons/
%{_kf6_includedir}/KWidgetsAddons/
%{_kf6_libdir}/libKF6WidgetsAddons.so
%{_kf6_plugindir}/designer/kwidgetsaddons6widgets.so

%files -n libKF6WidgetsAddons6-lang -f kwidgetsaddons6.lang

%changelog
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Hide toolbar when not need (e.g. in tabbed view)
  * FontChoose: Allow setting font features when selecting font (kde#479686)
  * Expand tabbar in KPageView
  * [kjobwidgets] Store window in a QPointer (kde#491637)
  * Support page headers in KPageView
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * fix that last line in fonts list is only half visible (kde#488079)
  * avoid the creation of toplevel widget (kde#490712)
  * Remove unused license text
  * Partially revert cccaa8f89897146043a535d45a276e3a57412815
  * Deprecate KJobWidgets::setWindowHandle,windowHandle
  * Fix tab not highlighted in some cases
  * Fix multiple overlays being installed over tab (kde#490213)
  * Update version to 6.5.0
- Drop patch, merged upstream:
  * 0001-Partially-revert-cccaa8.patch
* Fri Jul 19 2024 Christophe Marin <christophe@krop.fr>
- Add upstream fix:
  * 0001-Partially-revert-cccaa8.patch
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Fix the since version of KJobWidgets::windowHandle,setWindowHandle
  * kjobwidgets: Force setWindow() creating a window handle
  * kjobwidgets: Add functions to associate QWindow with a KJob
  * KTitleWidget: restore size policies to Preferred & vertical centering (kde#488319)
  * KTitleWidget: do not autoFillBackground by default, drop StyledPanel frame (kde#)
  * Make compile fine without qt6.7 deprecated methods
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Fix KMessageWidget background color
  * KMessageWidget: Avoid calling polish() inside of palette update (kde#487247)
  * Use ellipsis character instead of three dots in UI strings
  * Skip tests that need GUI on Windows CI
  * KViewStateSerializer: fix docu: setTreeView -> setView
  * KBusyIndicatorWidget: fix warning when hiding on startup
* Mon May 27 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.2. Hotfix release:
  * Fix KMessageWidget background color
* Thu May 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.1:
  * KMessageWidget: Avoid calling polish() inside of palette
    update (kde#487247)
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * KViewStateSerializer: fix docu: setTreeView -> setView
  * KBusyIndicatorWidget: fix warning when hiding on startup
  * Introduce KContextualHelpButton
  * KMessageWidget: Fix handling of palette changes
  * KMessageWidget: Make sure icon label is always vertically centered
  * gitignore: add VS Code dir
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * KPasswordLineEdit: Add toggle password visibility in context menu
  * We use KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(6, 0) in header. Use the same in cpp
  * Unify enums
  * Rename to normal reveal mode to OnlyNew
  * Port internal usage of revealPasswordAvailable
  * KPasswordLineEdit: replace revealPasswordAvailable property by an enum
  * Expose readOnly from KPasswordLineEdit
  * update version for new release
  * KMultiTabBar: Create pixmap with explicit devicePixelRatio
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kwidgetsaddons
